@@ -1,3 +1,6 @@
+use utf8;
+use v5.10;
+
 package Perl::Version;
 
 use warnings;
@@ -5,7 +8,7 @@ use strict;
 use Carp;
 use Scalar::Util qw( blessed );
 
-our $VERSION = '1.015';
+our $VERSION = '1.016';
 
 use overload (
   '""'  => \&stringify,
@@ -125,6 +128,14 @@ sub _parse {
   my $format = { fields => 1 };
   my ( $pad, $pfx, $ver, $alp, $sfx ) = ( $1, $2, $3, $4, $5 );
 
+  $self->{original}{args} = [ @_ ];
+  $self->{original}{version} = $version;
+  $self->{original}{pad} = $pad;
+  $self->{original}{pfx} = $pfx;
+  $self->{original}{ver} = $ver;
+  $self->{original}{alp} = $alp;
+  $self->{original}{sfx} = $sfx;
+
   # Decode version into format
   $format->{prefix} = $pad . $pfx;
   $format->{suffix} = $sfx;
@@ -354,12 +365,12 @@ sub set {
   my $self  = shift;
   my $other = shift;
 
-  $other = __PACKAGE__->new( $other ) unless ref $other;
+  $other = $self->new( $other ) unless ref $other;
 
   my @comp = $other->components;
-
   $self->components( \@comp );
   $self->alpha( $other->alpha );
+  $self->{format}{alpha} = $other->{format}{alpha};
 }
 
 1;
@@ -373,7 +384,7 @@ Perl::Version - Parse and manipulate Perl version strings
 
 =head1 VERSION
 
-This document describes Perl::Version version 1.015
+This document describes Perl::Version version 1.016
 
 =head1 SYNOPSIS
 
@@ -518,12 +529,15 @@ Simple versions with three or more components.
 
 Versions with a leading 'v'.
 
-=item Z<> 5.008006
+=item Z<> 5.8, 5.08, 5.008006
 
-Fielded numeric versions. You'll likely have seen this in relation to
-versions of Perl itself. If a version string has a single decimal point
-and the part after the point is three more more digits long, components
-are extracted from each group of three digits in the fractional part.
+Fielded numeric versions. If a version string has a single decimal
+point, it extracts digits in groups of three after the decimal point.
+If there are fewer than three digits in the final group, the field is
+left-padded with zeros to make it three digits (for example, 5.8
+becomes 5.008 and 5.08 becomes 5.008 too). This is opposite of how
+Perl and CPAN has historically treated versions by right padding
+groups of three on.
 
 For example
 
@@ -855,7 +869,7 @@ Return a normalised representation of a version.
 
 prints
 
-    v5.8.7_001
+    v5.8.7_01
 
 =item C<< numify >>
 
